@@ -1,9 +1,12 @@
 pub mod array;
 pub mod bit_util;
+#[cfg(feature = "compute")]
+pub mod compute;
 pub mod error;
 pub mod is_valid;
 pub mod kernels;
 pub mod prelude;
 pub mod trusted_len;
 pub mod utils;
+
 pub use arrow;
